==> devhelp-3.29.2.tar.xz: devhelp-3.29.2/devhelp/devhelp.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of Devhelp.
 *
 * Copyright (C) 2012 Aleksander Morgado <aleksander@gnu.org>
 *
 * Devhelp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * Devhelp is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Devhelp.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DEVHELP_H
#define DEVHELP_H

/* Include all the public headers. */

#include <devhelp/dh-enum-types.h>

#include <devhelp/dh-assistant-view.h>
#include <devhelp/dh-book.h>
#include <devhelp/dh-book-list.h>
#include <devhelp/dh-book-list-builder.h>
#include <devhelp/dh-book-list-directory.h>
#include <devhelp/dh-book-manager.h>
#include <devhelp/dh-book-tree.h>
#include <devhelp/dh-completion.h>
#include <devhelp/dh-init.h>
#include <devhelp/dh-keyword-model.h>
#include <devhelp/dh-link.h>
#include <devhelp/dh-profile.h>
#include <devhelp/dh-profile-builder.h>
#include <devhelp/dh-settings.h>
#include <devhelp/dh-settings-builder.h>
#include <devhelp/dh-sidebar.h>

#endif /* DEVHELP_H */

==> devhelp-3.29.3.tar.xz: devhelp-3.29.3/devhelp/devhelp.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 8 -*- */
/*
 * This file is part of Devhelp.
 *
 * Copyright (C) 2012 Aleksander Morgado <aleksander@gnu.org>
 *
 * Devhelp is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * Devhelp is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Devhelp.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef DEVHELP_H
#define DEVHELP_H

/* Include all the public headers. */

#include <devhelp/dh-enum-types.h>

#include <devhelp/dh-assistant-view.h>
#include <devhelp/dh-book.h>
#include <devhelp/dh-book-list.h>
#include <devhelp/dh-book-list-builder.h>
#include <devhelp/dh-book-list-directory.h>
#include <devhelp/dh-book-manager.h>
#include <devhelp/dh-book-tree.h>
#include <devhelp/dh-completion.h>
#include <devhelp/dh-init.h>
#include <devhelp/dh-keyword-model.h>
#include <devhelp/dh-link.h>
#include <devhelp/dh-notebook.h>
#include <devhelp/dh-profile.h>
#include <devhelp/dh-profile-builder.h>
#include <devhelp/dh-search-bar.h>
#include <devhelp/dh-settings.h>
#include <devhelp/dh-settings-builder.h>
#include <devhelp/dh-sidebar.h>
#include <devhelp/dh-tab.h>
#include <devhelp/dh-tab-label.h>
#include <devhelp/dh-web-view.h>
#include <devhelp/dh-window.h>

#endif /* DEVHELP_H */
